Struct googapis::google::cloud::aiplatform::v1beta1::ListDatasetsRequest [−][src]
pub struct ListDatasetsRequest {
pub parent: String,
pub filter: String,
pub page_size: i32,
pub page_token: String,
pub read_mask: Option<FieldMask>,
pub order_by: String,
}Expand description
Request message for [DatasetService.ListDatasets][google.cloud.aiplatform.v1beta1.DatasetService.ListDatasets].
Fields
parent: StringRequired. The name of the Dataset’s parent resource.
Format: projects/{project}/locations/{location}
filter: StringAn expression for filtering the results of the request. For field names both snake_case and camelCase are supported.
display_name: supports = and !=metadata_schema_uri: supports = and !=labelssupports general map functions that is:labels.key=value- key:value equality- `labels.key:* or labels:key - key existence
- A key including a space must be quoted.
labels."a key".
Some examples:
displayName="myDisplayName"labels.myKey="myValue"
page_size: i32The standard list page size.
page_token: StringThe standard list page token.
read_mask: Option<FieldMask>Mask specifying which fields to read.
order_by: StringA comma-separated list of fields to order by, sorted in ascending order. Use “desc” after a field name for descending. Supported fields:
display_namecreate_timeupdate_time